export declare enum LoggerModes {
    Console = "CONSOLE",
    File = "FILE",
    Custom = "CUSTOM",
    Off = "OFF"
}
export declare enum Formats {
    Line = "LINE",
    Json = "JSON"
}
declare const levels: {
    info: {
        color: string;
        prefix: string;
    };
    imp: {
        color: string;
        prefix: string;
    };
    warn: {
        color: string;
        prefix: string;
    };
    err: {
        color: string;
        prefix: string;
    };
};
declare type TLevelProp = typeof levels[keyof typeof levels];
declare type TJetLogger = ReturnType<typeof JetLogger>;
export declare type TCustomLogger = (timestamp: Date, prefix: string, content: any) => void;
export declare function JetLogger(mode?: LoggerModes, filePath?: string, timestamp?: boolean, format?: Formats, customLogger?: TCustomLogger): {
    readonly settings: {
        readonly mode: LoggerModes;
        readonly filePath: string;
        readonly timestamp: boolean;
        readonly format: Formats;
        readonly customLogger: TCustomLogger | undefined;
    };
    readonly info: typeof info;
    readonly imp: typeof imp;
    readonly warn: typeof warn;
    readonly err: typeof err;
    readonly printLog: typeof printLog;
};
declare function info(this: TJetLogger, content: any, printFull?: boolean): void;
declare function imp(this: TJetLogger, content: any, printFull?: boolean): void;
declare function warn(this: TJetLogger, content: any, printFull?: boolean): void;
declare function err(this: TJetLogger, content: any, printFull?: boolean): void;
declare function printLog(this: TJetLogger, content: any, printFull: boolean, level: TLevelProp): void;
declare const _default: {
    readonly settings: {
        readonly mode: LoggerModes;
        readonly filePath: string;
        readonly timestamp: boolean;
        readonly format: Formats;
        readonly customLogger: TCustomLogger | undefined;
    };
    readonly info: typeof info;
    readonly imp: typeof imp;
    readonly warn: typeof warn;
    readonly err: typeof err;
    readonly printLog: typeof printLog;
};
export default _default;
